from a10sdk.common.A10BaseClass import A10BaseClass


class System(A10BaseClass):
    
    """Class Description::
    Enable system group traps.

    Class system supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param all: {"default": 0, "optional": true, "type": "number", "description": "Enable all system group traps", "format": "flag"}
    :param data_cpu_high: {"default": 0, "optional": true, "type": "number", "description": "Enable data CPU usage high trap", "format": "flag"}
    :param power: {"default": 0, "optional": true, "type": "number", "description": "Enable system power supply trap", "format": "flag"}
    :param start: {"default": 0, "optional": true, "type": "number", "description": "Enable system start trap", "format": "flag"}
    :param high_memory_use: {"default": 0, "optional": true, "type": "number", "description": "Enable system high memory usage trap", "format": "flag"}
    :param pri_disk: {"default": 0, "optional": true, "type": "number", "description": "Enable system primary hard disk trap", "format": "flag"}
    :param file_sys_read_only: {"default": 0, "optional": true, "type": "number", "description": "Enable file system read-only trap", "format": "flag"}
    :param high_temp: {"default": 0, "optional": true, "type": "number", "description": "Enable system high temperature trap", "format": "flag"}
    :param sec_disk: {"default": 0, "optional": true, "type": "number", "description": "Enable system secondary hard disk trap", "format": "flag"}
    :param high_disk_use: {"default": 0, "optional": true, "type": "number", "description": "Enable system high disk usage trap", "format": "flag"}
    :param fan: {"default": 0, "optional": true, "type": "number", "description": "Enable system fan trap", "format": "flag"}
    :param shutdown: {"default": 0, "optional": true, "type": "number", "description": "Enable system shutdown trap", "format": "flag"}
    :param control_cpu_high: {"default": 0, "optional": true, "type": "number", "description": "Enable control CPU usage high trap", "format": "flag"}
    :param license_management: {"default": 0, "optional": true, "type": "number", "description": "Enable license management traps", "format": "flag"}
    :param packet_drop: {"default": 0, "optional": true, "type": "number", "description": "Enable system packet dropped trap", "format": "flag"}
    :param restart: {"default": 0, "optional": true, "type": "number", "description": "Enable system restart trap", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/snmp-server/enable/traps/system`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "system"
        self.a10_url="/axapi/v3/snmp-server/enable/traps/system"
        self.DeviceProxy = ""
        self.A10WW_all = ""
        self.data_cpu_high = ""
        self.power = ""
        self.start = ""
        self.high_memory_use = ""
        self.pri_disk = ""
        self.file_sys_read_only = ""
        self.high_temp = ""
        self.sec_disk = ""
        self.high_disk_use = ""
        self.fan = ""
        self.shutdown = ""
        self.control_cpu_high = ""
        self.license_management = ""
        self.packet_drop = ""
        self.restart = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Sip(A10BaseClass):
    
    """Class Description::
    SIP type.

    Class sip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param sip_port: {"description": "Specify the SIP port, default is 5060 (Port Number)", "format": "number", "default": 5060, "optional": true, "maximum": 65534, "minimum": 1, "type": "number"}
    :param expect_response_code: {"description": "Specify accepted response codes (e.g. 200, 400-430, any) (Format is xxx,xxx-xxx,any (xxx between [100,899]))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param sip: {"default": 0, "optional": true, "type": "number", "description": "SIP type", "format": "flag"}
    :param sip_tcp: {"default": 0, "optional": true, "type": "number", "description": "Use TCP for transmission, default is UDP", "format": "flag"}
    :param register: {"default": 0, "optional": true, "type": "number", "description": "Send SIP REGISTER message, default is to send OPTION message", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/sip`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "sip"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/sip"
        self.DeviceProxy = ""
        self.sip_port = ""
        self.expect_response_code = ""
        self.sip = ""
        self.sip_tcp = ""
        self.register = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Network(A10BaseClass):
    
    """Class Description::
    Configure Network Command.

    Class network supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vlan_list: {"minItems": 1, "items": {"type": "vlan"}, "uniqueItems": true, "array": [{"required": ["vlan-num"], "properties": {"ve": {"description": "ve number", "format": "number", "type": "number", "maximum": 4094, "minimum": 2, "optional": true}, "untagged-trunk-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"untagged-trunk-start": {"type": "number", "description": "Trunk groups", "format": "number"}, "optional": true, "untagged-trunk-end": {"type": "number", "description": "Trunk Group", "format": "number"}}}]}, "untagged-lif": {"description": "Logical tunnel interface (Logical tunnel interface number)", "format": "number", "type": "number", "maximum": 128, "minimum": 1, "optional": true}, "untagged-eth-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"untagged-ethernet-end": {"type": "number", "description": "Ethernet port", "format": "interface"}, "untagged-ethernet-start": {"$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet port (Interface number)", "format": "interface"}, "optional": true}}]}, "tagged-eth-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"tagged-ethernet-end": {"type": "number", "description": "Ethernet port", "format": "interface"}, "optional": true, "tagged-ethernet-start": {"$ref": "/axapi/v3/interface/ethernet", "type": "number", "description": "Ethernet port (Interface number)", "format": "interface"}}}]}, "tagged-trunk-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "tagged-trunk-start": {"type": "number", "description": "Trunk groups", "format": "number"}, "tagged-trunk-end": {"type": "number", "description": "Trunk Group", "format": "number"}}}]}, "vlan-num": {"description": "VLAN number", "format": "number", "type": "number", "maximum": 4094, "minimum": 2, "optional": false}, "name": {"description": "VLAN name", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/network/vlan/{vlan-num}"}
    :param lacp_passthrough_list: {"minItems": 1, "items": {"type": "lacp-passthrough"}, "uniqueItems": true, "array": [{"required": ["peer-from", "peer-to"], "properties": {"peer-from": {"optional": false, "type": "number", "description": "Peer member to forward received LACP packets", "format": "interface"}, "peer-to": {"optional": false, "type": "number", "description": "Peer member to forward received LACP packets", "format": "interface"}}}], "type": "array", "$ref": "/axapi/v3/network/lacp-passthrough/{peer-from}+{peer-to}"}
    :param bpdu_fwd_group_list: {"minItems": 1, "items": {"type": "bpdu-fwd-group"}, "uniqueItems": true, "array": [{"required": ["bpdu-fwd-group-number"], "properties": {"bpdu-fwd-group-number": {"optional": false, "minimum": 1, "type": "number", "maximum": 8, "format": "number"}, "ethernet-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ethernet-start": {"type": "number", "description": "Ethernet Port (Interface number)", "format": "interface"}, "ethernet-end": {"type": "number", "description": "Ethernet Port", "format": "interface"}, "optional": true}}]}}}], "type": "array", "$ref": "/axapi/v3/network/bpdu-fwd-group/{bpdu-fwd-group-number}"}
    :param bridge_vlan_group_list: {"minItems": 1, "items": {"type": "bridge-vlan-group"}, "uniqueItems": true, "array": [{"required": ["bridge-vlan-group-number"], "properties": {"ve": {"description": "Virtual Ethernet Port (Virtual Ethernet Port number)", "format": "number", "type": "number", "maximum": 4094, "minimum": 2, "optional": true}, "vlan-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"optional": true, "vlan-start": {"$ref": "/axapi/v3/network/vlan", "type": "number", "description": "VLAN id", "format": "number"}, "vlan-end": {"type": "number", "description": "VLAN id", "format": "number"}}}]}, "forward-traffic": {"description": "'forward-all-traffic': Forward all traffic between bridge members; 'forward-ip-traffic': Forward only IP traffic between bridge members (default); ", "format": "enum", "default": "forward-ip-traffic", "type": "string", "enum": ["forward-all-traffic", "forward-ip-traffic"], "optional": true}, "bridge-vlan-group-number": {"description": "Bridge VLAN Group Number", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": false}, "name": {"description": "Bridge Group Name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/network/bridge-vlan-group/{bridge-vlan-group-number}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "network"
        self.a10_url="/axapi/v3/network"
        self.DeviceProxy = ""
        self.arp = {}
        self.vlan_list = []
        self.lacp_passthrough_list = []
        self.bpdu_fwd_group_list = []
        self.vlan_global = {}
        self.ve_stats = {}
        self.mac_age_time = {}
        self.icmpv6_rate_limit = {}
        self.lacp = {}
        self.arp_timeout = {}
        self.bfd = {}
        self.icmp_rate_limit = {}
        self.bridge_vlan_group_list = []
        self.mac_address = {}
        self.lldp = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class PacketsPerSecond(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param min: {"description": "Minimum packets-per-second threshold (per CPU) before redistribution will take effect (Minimum packets-per-second threshold (per CPU) before redistribution will take effect (default: 100000))", "format": "number", "default": 100000, "maximum": 30000000, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "packets-per-second"
        self.DeviceProxy = ""
        self.A10WW_min = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CpuUsage(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param high: {"description": "CPU usage threshold (percentage) that will trigger the redistribution (default: 75)", "format": "number", "default": 75, "maximum": 100, "minimum": 0, "type": "number"}
    :param low: {"description": "CPU usage threshold (percentage) that will restore the normal packet distribution (default: 60)", "format": "number", "default": 60, "maximum": 100, "minimum": 0, "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cpu-usage"
        self.DeviceProxy = ""
        self.high = ""
        self.low = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CpuLoadSharing(A10BaseClass):
    
    """Class Description::
    Redistribute packets uniformly to all CPUs during overload situations.

    Class cpu-load-sharing supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param disable: {"default": 0, "optional": true, "type": "number", "description": "Disable CPU load sharing in overload situations", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/system/cpu-load-sharing`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "cpu-load-sharing"
        self.a10_url="/axapi/v3/system/cpu-load-sharing"
        self.DeviceProxy = ""
        self.packets_per_second = {}
        self.cpu_usage = {}
        self.disable = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ClassList(A10BaseClass):
    
    """Class Description::
    Configure classification list.

    Class class-list supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param header_name: {"description": "Specify L7 header name", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param client_ip_l7_header: {"description": "Use extract client IP address from L7 header", "format": "flag", "default": 0, "optional": true, "not": "client-ip-l3-dest", "type": "number"}
    :param client_ip_l3_dest: {"description": "Use destination IP as client IP address", "format": "flag", "default": 0, "optional": true, "not": "client-ip-l7-header", "type": "number"}
    :param lid_list: {"minItems": 1, "items": {"type": "lid"}, "uniqueItems": true, "array": [{"required": ["lidnum"], "properties": {"request-limit": {"description": "Request limit (Specify request limit)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}, "conn-limit": {"description": "Connection limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 0, "optional": true}, "interval": {"description": "Specify log interval in minutes, by default system will log every over limit instance", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": true}, "log": {"default": 0, "optional": true, "type": "number", "description": "Log a message", "format": "flag"}, "dns64": {"type": "object", "properties": {"exclusive-answer": {"default": 0, "type": "number", "description": "Exclusive Answer in DNS Response", "format": "flag"}, "prefix": {"type": "string", "description": "IPv6 prefix", "format": "ipv6-address-plen"}, "disable": {"default": 0, "type": "number", "description": "Disable", "format": "flag"}}}, "lidnum": {"description": "Specify a limit ID", "format": "number", "type": "number", "maximum": 31, "minimum": 1, "optional": false}, "request-rate-limit": {"description": "Request rate limit (Specify request rate limit)", "format": "number", "type": "number", "maximum": 4294967295, "minimum": 1, "optional": true}, "conn-per": {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "request-per": {"description": "Per (Specify interval in number of 100ms)", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "conn-rate-limit": {"description": "Specify connection rate limit", "format": "number", "type": "number", "maximum": 2147483647, "minimum": 1, "optional": true}, "lockout": {"description": "Don't accept any new connection for certain time (Lockout duration in minutes)", "format": "number", "type": "number", "maximum": 1023, "minimum": 1, "optional": true}, "action-value": {"optional": true, "enum": ["forward", "reset"], "type": "string", "description": "'forward': Forward the traffic even it exceeds limit; 'reset': Reset the connection when it exceeds limit; ", "format": "enum"}, "over-limit-action": {"default": 0, "optional": true, "type": "number", "description": "Set action when exceeds limit", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/slb/template/policy/{name}/class-list/lid/{lidnum}"}
    :param name: {"description": "Class list name or geo-location-class-list name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/policy/{name}/class-list`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "class-list"
        self.a10_url="/axapi/v3/slb/template/policy/{name}/class-list"
        self.DeviceProxy = ""
        self.header_name = ""
        self.client_ip_l7_header = ""
        self.client_ip_l3_dest = ""
        self.lid_list = []
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Rules(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param host_v6: {"type": "string", "description": "IPv6 Host Address", "format": "ipv6-address"}
    :param subnet: {"type": "string", "description": "IPv4 Network Address", "format": "ipv4-address"}
    :param host_v4: {"type": "string", "description": "IPv4 Host Address", "format": "ipv4-address"}
    :param description: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Description of the object-group instance", "format": "string-rlx"}
    :param ipv6_subnet: {"type": "string", "description": "IPv6 Network Address", "format": "ipv6-address-plen"}
    :param seq_num: {"description": "Sequence number", "minimum": 1, "type": "number", "maximum": 8192, "format": "number"}
    :param rev_subnet_mask: {"type": "string", "description": "Network Mask. 0=apply, 255=ignore", "format": "ipv4-rev-netmask"}
    :param any: {"default": 0, "type": "number", "description": "Any host", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "rules"
        self.DeviceProxy = ""
        self.host_v6 = ""
        self.subnet = ""
        self.host_v4 = ""
        self.description = ""
        self.ipv6_subnet = ""
        self.seq_num = ""
        self.rev_subnet_mask = ""
        self.A10WW_any = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Network(A10BaseClass):
    
    """Class Description::
    Configure Network Object Group.

    Class network supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param rules: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"host-v6": {"type": "string", "description": "IPv6 Host Address", "format": "ipv6-address"}, "subnet": {"type": "string", "description": "IPv4 Network Address", "format": "ipv4-address"}, "host-v4": {"type": "string", "description": "IPv4 Host Address", "format": "ipv4-address"}, "description": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Description of the object-group instance", "format": "string-rlx"}, "ipv6-subnet": {"type": "string", "description": "IPv6 Network Address", "format": "ipv6-address-plen"}, "seq-num": {"description": "Sequence number", "minimum": 1, "type": "number", "maximum": 8192, "format": "number"}, "rev-subnet-mask": {"type": "string", "description": "Network Mask. 0=apply, 255=ignore", "format": "ipv4-rev-netmask"}, "optional": true, "any": {"default": 0, "type": "number", "description": "Any host", "format": "flag"}}}]}
    :param net_name: {"description": "Network Object Name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/object-group/network/{net_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "net_name"]

        self.b_key = "network"
        self.a10_url="/axapi/v3/object-group/network/{net_name}"
        self.DeviceProxy = ""
        self.rules = []
        self.net_name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Server(A10BaseClass):
    
    """Class Description::
    Server template.

    Class server supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param health_check_disable: {"description": "Disable configured health check configuration", "format": "flag", "default": 0, "optional": true, "not": "health-check", "type": "number"}
    :param stats_data_action: {"description": "'stats-data-enable': Enable statistical data collection for real server; 'stats-data-disable': Disable statistical data collection for real server; ", "format": "enum", "default": "stats-data-enable", "type": "string", "enum": ["stats-data-enable", "stats-data-disable"], "optional": true}
    :param spoofing_cache: {"default": 0, "optional": true, "type": "number", "description": "Servers under the template are spoofing cache", "format": "flag"}
    :param weight: {"description": "Weight for the Real Servers (Connection Weight)", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}
    :param slow_start: {"default": 0, "optional": true, "type": "number", "description": "Slowly ramp up the connection number after server is up", "format": "flag"}
    :param conn_limit: {"description": "Connection limit", "format": "number", "type": "number", "maximum": 8000000, "minimum": 1, "optional": true}
    :param initial_slow_start: {"description": "Initial slow start connection limit (default 128)", "format": "number", "default": 128, "optional": true, "maximum": 4095, "minimum": 1, "type": "number"}
    :param max_dynamic_server: {"description": "Maximum dynamic server number (Maximum dynamic server number (default is 255))", "format": "number", "default": 255, "optional": true, "maximum": 1023, "minimum": 1, "type": "number"}
    :param rate_interval: {"description": "'100ms': Use 100 ms as sampling interval; 'second': Use 1 second as sampling interval; ", "format": "enum", "default": "second", "type": "string", "enum": ["100ms", "second"], "optional": true}
    :param till: {"description": "Slow start ends when slow start connection limit reaches a number (default 4096) (Slow start ends when connection limit reaches this number)", "format": "number", "default": 4096, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}
    :param add: {"description": "Slow start connection limit add by a number every interval (Add by this number every interval)", "format": "number", "optional": true, "maximum": 4095, "minimum": 1, "not": "times", "type": "number"}
    :param min_ttl_ratio: {"description": "Minimum TTL to DNS query interval ratio (Minimum TTL ratio (default is 2))", "format": "number", "default": 2, "optional": true, "maximum": 15, "minimum": 1, "type": "number"}
    :param dynamic_server_prefix: {"description": "Prefix of dynamic server (Prefix of dynamic server (default is \"DRS\"))", "format": "string", "default": "DRS", "minLength": 1, "optional": true, "maxLength": 3, "type": "string"}
    :param resume: {"description": "Resume accepting new connection after connection number drops below threshold (Connection resume threshold)", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}
    :param every: {"description": "Slow start connection limit increment interval (default 10)", "format": "number", "default": 10, "optional": true, "maximum": 60, "minimum": 1, "type": "number"}
    :param conn_limit_no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param extended_stats: {"default": 0, "optional": true, "type": "number", "description": "Enable extended statistics on real server", "format": "flag"}
    :param conn_rate_limit_no_logging: {"default": 0, "optional": true, "type": "number", "description": "Do not log connection over limit event", "format": "flag"}
    :param name: {"description": "Server template name", "format": "string", "default": "default", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param times: {"description": "Slow start connection limit multiply by a number every interval (default 2) (Multiply by this number every interval)", "format": "number", "default": 2, "optional": true, "maximum": 10, "minimum": 2, "not": "add", "type": "number"}
    :param log_selection_failure: {"default": 0, "optional": true, "type": "number", "description": "Enable real-time logging for server selection failure event", "format": "flag"}
    :param conn_rate_limit: {"description": "Connection rate limit", "format": "number", "type": "number", "maximum": 1048575, "minimum": 1, "optional": true}
    :param dns_query_interval: {"description": "The interval to query DNS server for the hostname (DNS query interval (in minute, default is 10))", "format": "number", "default": 10, "optional": true, "maximum": 1440, "minimum": 1, "type": "number"}
    :param health_check: {"description": "Health Check Monitor (Health monitor name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "not": "health-check-disable", "type": "string", "$ref": "/axapi/v3/health/monitor"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/server/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "server"
        self.a10_url="/axapi/v3/slb/template/server/{name}"
        self.DeviceProxy = ""
        self.health_check_disable = ""
        self.stats_data_action = ""
        self.spoofing_cache = ""
        self.weight = ""
        self.slow_start = ""
        self.conn_limit = ""
        self.initial_slow_start = ""
        self.max_dynamic_server = ""
        self.rate_interval = ""
        self.till = ""
        self.add = ""
        self.min_ttl_ratio = ""
        self.dynamic_server_prefix = ""
        self.resume = ""
        self.every = ""
        self.conn_limit_no_logging = ""
        self.extended_stats = ""
        self.conn_rate_limit_no_logging = ""
        self.name = ""
        self.times = ""
        self.log_selection_failure = ""
        self.conn_rate_limit = ""
        self.dns_query_interval = ""
        self.health_check = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Relay(A10BaseClass):
    
    """Class Description::
    Authentication relay configuration.

    Class relay supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ntlm_list: {"minItems": 1, "items": {"type": "ntlm"}, "uniqueItems": true, "array": [{"required": ["name"], "properties": {"domain": {"description": "Specify NTLM domain, default is null", "format": "string", "minLength": 1, "optional": true, "maxLength": 64, "type": "string"}, "version": {"description": "Specify NTLM version, default is NTLM 2", "format": "number", "default": 2, "optional": true, "maximum": 2, "minimum": 1, "type": "number"}, "name": {"description": "Specify NTLM authentication relay name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/aam/authentication/relay/ntlm/{name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/relay`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "relay"
        self.a10_url="/axapi/v3/aam/authentication/relay"
        self.DeviceProxy = ""
        self.ntlm_list = []
        self.form_based = {}
        self.kerberos = {}
        self.http_basic = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Import(A10BaseClass):
    
    """    :param geo_location: {"description": "Geo-location CSV File", "partition-visibility": "shared", "minLength": 1, "format": "string", "optional": true, "maxLength": 63, "type": "string"}
    :param ssl_cert_key: {"optional": true, "enum": ["bulk"], "type": "string", "description": "'bulk': import an archive file; ", "format": "enum"}
    :param bw_list: {"description": "Black white List File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param auth_portal: {"description": "Portal file for http authentication", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param aflex: {"description": "aFleX Script Source File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param overwrite: {"default": 0, "optional": true, "type": "number", "description": "Overwrite existing file", "format": "flag"}
    :param pfx_password: {"description": "The password for certificate file (pfx type only)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param class_list: {"description": "Class List File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param policy: {"description": "WAF policy File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param auth_portal_image: {"description": "Image file for default portal", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param csr_generate: {"default": 0, "optional": true, "type": "number", "description": "Generate CSR file", "format": "flag"}
    :param ssl_crl: {"description": "SSL Crl File", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param remote_file: {"not": "store-name", "optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}
    :param dnssec_ds: {"description": "DNSSEC DS file for child zone", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param local_uri_file: {"description": "Local URI files for http response", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param wsdl: {"description": "Web Service Definition Language File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param ssl_key: {"description": "SSL Key File(enter bulk when import an archive file)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param geo_location_class_list: {"description": "Geo-location Class-list file", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param license: {"description": "License File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param store_name: {"description": "Import store name", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "not": "remote-file", "type": "string"}
    :param ca_cert: {"description": "CA Cert File(enter bulk when import an archive file)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param lw_4o6: {"description": "LW-4over6 Binding Table File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param xml_schema: {"description": "XML-Schema File", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param certificate_type: {"optional": true, "enum": ["pem", "der", "pfx", "p7b"], "type": "string", "description": "'pem': pem; 'der': der; 'pfx': pfx; 'p7b': p7b; ", "format": "enum"}
    :param ssl_cert: {"description": "SSL Cert File(enter bulk when import an archive file)", "format": "string", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param dnssec_dnskey: {"description": "DNSSEC DNSKEY(KSK) file for child zone", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Get files from remote site.

    Class import supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/import`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "import"
        self.a10_url="/axapi/v3/import"
        self.DeviceProxy = ""
        self.geo_location = ""
        self.ssl_cert_key = ""
        self.bw_list = ""
        self.health_external = {}
        self.auth_portal = ""
        self.aflex = ""
        self.overwrite = ""
        self.pfx_password = ""
        self.class_list = ""
        self.health_postfile = {}
        self.policy = ""
        self.store = {}
        self.auth_portal_image = ""
        self.csr_generate = ""
        self.ssl_crl = ""
        self.remote_file = ""
        self.dnssec_ds = ""
        self.local_uri_file = ""
        self.wsdl = ""
        self.ssl_key = ""
        self.geo_location_class_list = ""
        self.use_mgmt_port = ""
        self.A10WW_license = ""
        self.store_name = ""
        self.ca_cert = ""
        self.lw_4o6 = ""
        self.xml_schema = ""
        self.certificate_type = ""
        self.auth_saml_idp = {}
        self.ssl_cert = ""
        self.dnssec_dnskey = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class OneToOne(A10BaseClass):
    
    """Class Description::
    Set one-to-one NAT parameters.

    Class one-to-one supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param pool_group_list: {"minItems": 1, "items": {"type": "pool-group"}, "uniqueItems": true, "array": [{"required": ["pool-group-name"], "properties": {"member-list": {"minItems": 1, "items": {"type": "member"}, "uniqueItems": true, "array": [{"required": ["pool-name"], "properties": {"pool-name": {"description": "Specify CGNv6 one-to-one pool name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/one-to-one/pool-group/{pool-group-name}/member/{pool-name}"}, "pool-group-name": {"description": "Specify pool group name", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}, "vrid": {"description": "Specify VRRP-A vrid", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/one-to-one/pool-group/{pool-group-name}"}
    :param pool_list: {"minItems": 1, "items": {"type": "pool"}, "uniqueItems": true, "array": [{"required": ["pool-name"], "properties": {"partition": {"description": "Share with a single partition (Partition Name)", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 14, "type": "string"}, "group": {"description": "Share with a partition group (Partition Group Name)", "format": "string", "minLength": 1, "modify-not-allowed": 1, "optional": true, "maxLength": 63, "type": "string"}, "start-address": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure start IP address of NAT pool", "format": "ipv4-address"}, "vrid": {"description": "Configure VRRP-A vrid (Specify ha VRRP-A vrid)", "format": "number", "optional": true, "maximum": 31, "minimum": 1, "modify-not-allowed": 1, "type": "number"}, "netmask": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure mask for pool", "format": "ipv4-netmask-brief"}, "end-address": {"optional": true, "modify-not-allowed": 1, "type": "string", "description": "Configure end IP address of NAT pool", "format": "ipv4-address"}, "shared": {"description": "Share this pool with other partitions (default: not shared)", "partition-visibility": "shared", "default": 0, "optional": true, "format": "flag", "modify-not-allowed": 1, "type": "number"}, "pool-name": {"description": "Specify pool name or pool group", "format": "string-rlx", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/one-to-one/pool/{pool-name}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/one-to-one`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "one-to-one"
        self.a10_url="/axapi/v3/cgnv6/one-to-one"
        self.DeviceProxy = ""
        self.pool_group_list = []
        self.A10WW_global = {}
        self.pool_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class KerberosCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tcp_only: {"default": 0, "type": "number", "description": "Specify the kerberos tcp only", "format": "flag"}
    :param kpasswd_pricipal_name: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the pricipal name", "format": "string-rlx"}
    :param kinit_password: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Password", "format": "password"}
    :param kpasswd_password: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Password", "format": "password"}
    :param kpasswd: {"default": 0, "not-list": ["kinit", "kadmin"], "type": "number", "description": "Kerberos change passwd", "format": "flag"}
    :param kinit_pricipal_name: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the pricipal name", "format": "string-rlx"}
    :param kpasswd_kdc: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the kdc server, host|ip [:port]", "format": "string-rlx"}
    :param kpasswd_server: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the Kerberos password server, host|ip [:port]", "format": "string-rlx"}
    :param kadmin_encrypted: {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param kinit: {"default": 0, "not-list": ["kadmin", "kpasswd"], "type": "number", "description": "Kerberos KDC", "format": "flag"}
    :param kadmin_pricipal_name: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify the pricipal name", "format": "string-rlx"}
    :param kadmin_realm: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the realm", "format": "string-rlx"}
    :param kinit_kdc: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the kdc server, host|ip [:port]", "format": "string-rlx"}
    :param kinit_encrypted: {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param kadmin: {"default": 0, "not-list": ["kinit", "kpasswd"], "type": "number", "description": "Kerberos admin", "format": "flag"}
    :param kadmin_kdc: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the kdc server, host|ip [:port]", "format": "string-rlx"}
    :param kadmin_server: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify the admin server, host|ip [:port]", "format": "string-rlx"}
    :param kpasswd_encrypted: {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}
    :param kadmin_password: {"minLength": 1, "maxLength": 31, "type": "string", "description": "Password", "format": "password"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "kerberos-cfg"
        self.DeviceProxy = ""
        self.tcp_only = ""
        self.kpasswd_pricipal_name = ""
        self.kinit_password = ""
        self.kpasswd_password = ""
        self.kpasswd = ""
        self.kinit_pricipal_name = ""
        self.kpasswd_kdc = ""
        self.kpasswd_server = ""
        self.kadmin_encrypted = ""
        self.kinit = ""
        self.kadmin_pricipal_name = ""
        self.kadmin_realm = ""
        self.kinit_kdc = ""
        self.kinit_encrypted = ""
        self.kadmin = ""
        self.kadmin_kdc = ""
        self.kadmin_server = ""
        self.kpasswd_encrypted = ""
        self.kadmin_password = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class KerberosKdc(A10BaseClass):
    
    """Class Description::
    Kerberos KDC type.

    Class kerberos-kdc supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/health/monitor/{name}/method/kerberos-kdc`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "kerberos-kdc"
        self.a10_url="/axapi/v3/health/monitor/{name}/method/kerberos-kdc"
        self.DeviceProxy = ""
        self.kerberos_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param threshold_exceed: {"description": "Threshold exceeded count", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param lockout_drop: {"description": "Lockout drops", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param too_many_sessions: {"description": "Too many sessions consumed", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param sessions_freed: {"description": "Sessions freed", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param permitted: {"description": "Honor threshold  count", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param log_msg_sent: {"description": "Log messages sent", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param sessions_alloc: {"description": "Sessions allocated", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param out_of_sessions: {"description": "Out of sessions", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param called: {"description": "Threshold check count", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.threshold_exceed = ""
        self.lockout_drop = ""
        self.too_many_sessions = ""
        self.sessions_freed = ""
        self.permitted = ""
        self.log_msg_sent = ""
        self.sessions_alloc = ""
        self.out_of_sessions = ""
        self.called = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CrlSrcip(A10BaseClass):
    
    """Class Description::
    Statistics for the object crl-srcip.

    Class crl-srcip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/crl-srcip/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "crl-srcip"
        self.a10_url="/axapi/v3/slb/crl-srcip/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class BladeParameters(A10BaseClass):
    
    """Class Description::
    blade parameters of VRRP-A vrid.

    Class blade-parameters supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param priority: {"description": "VRRP-A priorty (Priority, default is 150)", "format": "number", "default": 150, "optional": true, "maximum": 255, "minimum": 1, "type": "number"}
    :param fail_over_policy_template: {"description": "Apply a fail over policy template (VRRP-A fail over policy template name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/vrrp-a/fail-over-policy-template"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/vrid/{vrid_val}/blade-parameters`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "blade-parameters"
        self.a10_url="/axapi/v3/vrrp-a/vrid/{vrid_val}/blade-parameters"
        self.DeviceProxy = ""
        self.priority = ""
        self.fail_over_policy_template = ""
        self.tracking_options = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param open_new_server_conn: {"description": "Open new server conn", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "8"}
    :param reuse_server_idle_conn: {"description": "Reuse idle server conn", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "8"}
    :param inc_aflow_limit: {"description": "Inc aFlow limit", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "8"}
    :param pause_conn_fail: {"description": "Pause connection fail", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param pause_conn: {"description": "Pause connection", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param event_resume_conn: {"description": "Resume conn by event", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param try_to_resume_conn: {"description": "Resume conn by trying", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param resume_conn: {"description": "Resume connection", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param retry_resume_conn: {"description": "Resume conn by retry", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "8"}
    :param error_resume_conn: {"description": "Resume conn by error", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "8"}
    :param timer_resume_conn: {"description": "Resume conn by timer", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.open_new_server_conn = ""
        self.reuse_server_idle_conn = ""
        self.inc_aflow_limit = ""
        self.pause_conn_fail = ""
        self.pause_conn = ""
        self.event_resume_conn = ""
        self.try_to_resume_conn = ""
        self.resume_conn = ""
        self.retry_resume_conn = ""
        self.error_resume_conn = ""
        self.timer_resume_conn = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Aflow(A10BaseClass):
    
    """Class Description::
    Statistics for the object aflow.

    Class aflow supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/aflow/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "aflow"
        self.a10_url="/axapi/v3/slb/aflow/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Dblb(A10BaseClass):
    
    """Class Description::
    DBLB template.

    Class dblb supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param server_version: {"optional": true, "enum": ["MSSQL2008", "MSSQL2012", "MySQL"], "type": "string", "description": "'MSSQL2008': MSSQL server 2008 or 2008 R2; 'MSSQL2012': MSSQL server 2012; 'MySQL': MySQL server (any version); ", "format": "enum"}
    :param name: {"description": "DBLB template name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param class_list: {"description": "Specify user/password string class list (Class list name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string", "$ref": "/axapi/v3/class-list"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/template/dblb/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "dblb"
        self.a10_url="/axapi/v3/slb/template/dblb/{name}"
        self.DeviceProxy = ""
        self.server_version = ""
        self.name = ""
        self.calc_sha1 = {}
        self.class_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class IpList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ip: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "ip-list"
        self.DeviceProxy = ""
        self.ip = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class MemberList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param port: {"type": "number", "format": "number"}
    :param priority: {"type": "number", "format": "number"}
    :param state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param ip_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}
    :param location: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param id: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "member-list"
        self.DeviceProxy = ""
        self.port = ""
        self.priority = ""
        self.state = ""
        self.ip_list = []
        self.location = ""
        self.A10WW_id = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param chassis_id: {"type": "number", "format": "number"}
    :param multicast_port: {"type": "number", "format": "number"}
    :param multicast_addr: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param version: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param member_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"port": {"type": "number", "format": "number"}, "priority": {"type": "number", "format": "number"}, "state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "ip-list": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ip": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true}}]}, "location": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "optional": true, "id": {"type": "number", "format": "number"}}}]}
    :param vcs_enabled: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.chassis_id = ""
        self.multicast_port = ""
        self.multicast_addr = ""
        self.version = ""
        self.member_list = []
        self.vcs_enabled = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VcsSummary(A10BaseClass):
    
    """Class Description::
    Operational Status for the object vcs-summary.

    Class vcs-summary supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vcs-summary/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "vcs-summary"
        self.a10_url="/axapi/v3/vcs-summary/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param call_req_pns_call_id_mismatch: {"description": "Call ID Mismatch on Call Request", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param gre_session_created: {"description": "GRE Session Created", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param gre_session_freed: {"description": "GRE Session Freed", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param call_reply_pns_call_id_mismatch: {"description": "Call ID Mismatch on Call Reply", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param calls_established: {"description": "Calls Established", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.call_req_pns_call_id_mismatch = ""
        self.gre_session_created = ""
        self.gre_session_freed = ""
        self.call_reply_pns_call_id_mismatch = ""
        self.calls_established = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Pptp(A10BaseClass):
    
    """Class Description::
    Statistics for the object pptp.

    Class pptp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/stateful-firewall/alg/pptp/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "pptp"
        self.a10_url="/axapi/v3/cgnv6/stateful-firewall/alg/pptp/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param server_fin: {"description": "Server FIN", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param curr_be_enc: {"description": "Curr BE Encryption Conns", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param total_be_enc: {"description": "Total BE Encryption Conns", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param total_proxy: {"description": "Total Proxy Conns", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param curr_proxy: {"description": "Curr Proxy Conns", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param commands: {"description": "DB commands reply", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param client_fin: {"description": "Client FIN", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param curr_fe_enc: {"description": "Curr FE Encryption Conns", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param queries: {"description": "DB Queries", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param session_err: {"description": "Session err", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param total_fe_enc: {"description": "Total FE Encryption Conns", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.server_fin = ""
        self.curr_be_enc = ""
        self.total_be_enc = ""
        self.total_proxy = ""
        self.curr_proxy = ""
        self.commands = ""
        self.client_fin = ""
        self.curr_fe_enc = ""
        self.queries = ""
        self.session_err = ""
        self.total_fe_enc = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Mysql(A10BaseClass):
    
    """Class Description::
    Statistics for the object mysql.

    Class mysql supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/slb/mysql/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "mysql"
        self.a10_url="/axapi/v3/slb/mysql/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Portal(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param new_pin_page: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new PIN page name for RSA-RADIUS", "format": "string-rlx"}
    :param portal_name: {"description": "Specify portal name", "format": "string", "minLength": 1, "maxLength": 63, "not": "default-portal", "type": "string"}
    :param default_portal: {"default": 0, "not": "portal-name", "type": "number", "description": "Use default portal", "format": "flag"}
    :param next_token_page: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify next token page name for RSA-RADIUS", "format": "string-rlx"}
    :param failpage: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logon fail page name (portal fail page name)", "format": "string-rlx"}
    :param changepasswordpage: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify change password page name", "format": "string-rlx"}
    :param logon: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logon page name", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "portal"
        self.DeviceProxy = ""
        self.new_pin_page = ""
        self.portal_name = ""
        self.default_portal = ""
        self.next_token_page = ""
        self.failpage = ""
        self.changepasswordpage = ""
        self.logon = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class LogonPageCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param action_url: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify form submission action url", "format": "string-rlx"}
    :param username_variable: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username variable name in form submission", "format": "string-rlx"}
    :param password_variable: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password variable name in form submission", "format": "string-rlx"}
    :param login_failure_message: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify login failure message shown in logon page (Specify error string, default is \"Invalid username or password. Please try again.\")", "format": "string-rlx"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "logon-page-cfg"
        self.DeviceProxy = ""
        self.action_url = ""
        self.username_variable = ""
        self.password_variable = ""
        self.login_failure_message = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class CpPageCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param cp_cfm_pwd_enum: {"enum": ["changepassword-password-confirm-variable"], "type": "string", "description": "'changepassword-password-confirm-variable': Specify password confirm variable name in form submission; ", "format": "enum"}
    :param cp_cfm_pwd_var: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify password confirm variable name", "format": "string-rlx"}
    :param cp_new_pwd_var: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify new password variable name", "format": "string-rlx"}
    :param changepassword_url: {"minLength": 1, "maxLength": 127, "type": "string", "description": "Specify changepassword form submission action url (changepassword action url)", "format": "string-rlx"}
    :param cp_new_pwd_enum: {"enum": ["changepassword-new-password-variable"], "type": "string", "description": "'changepassword-new-password-variable': Specify new password variable name in form submission; ", "format": "enum"}
    :param cp_old_pwd_enum: {"enum": ["changepassword-old-password-variable"], "type": "string", "description": "'changepassword-old-password-variable': Specify old password variable name in form submission; ", "format": "enum"}
    :param cp_user_var: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify username variable name", "format": "string-rlx"}
    :param cp_old_pwd_var: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify old password variable name", "format": "string-rlx"}
    :param cp_user_enum: {"enum": ["changepassword-username-variable"], "type": "string", "description": "'changepassword-username-variable': Specify username variable name in form submission; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "cp-page-cfg"
        self.DeviceProxy = ""
        self.cp_cfm_pwd_enum = ""
        self.cp_cfm_pwd_var = ""
        self.cp_new_pwd_var = ""
        self.changepassword_url = ""
        self.cp_new_pwd_enum = ""
        self.cp_old_pwd_enum = ""
        self.cp_user_var = ""
        self.cp_old_pwd_var = ""
        self.cp_user_enum = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class FormBased(A10BaseClass):
    
    """Class Description::
    Form-based Authentication Logon.

    Class form-based supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param retry: {"description": "Specify max. number of failure retry (Specify retry count (1 ~ 32), default is 3)", "format": "number", "default": 3, "optional": true, "maximum": 32, "minimum": 1, "type": "number"}
    :param name: {"description": "Specify form-based authentication logon name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param next_token_variable: {"description": "Specify next-token variable name in form submission", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param new_pin_variable: {"description": "Specify new-pin variable name in form submission", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/logon/form-based/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "form-based"
        self.a10_url="/axapi/v3/aam/authentication/logon/form-based/{name}"
        self.DeviceProxy = ""
        self.retry = ""
        self.name = ""
        self.next_token_variable = ""
        self.new_pin_variable = ""
        self.portal = {}
        self.logon_page_cfg = {}
        self.cp_page_cfg = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Protocol(A10BaseClass):
    
    """Class Description::
    Specify GSLB Message Protocol parameters.

    Class protocol supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port for connections", "format": "flag"}
    :param ping_site: {"description": "name of site or ip address to ping", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param auto_detect: {"default": 0, "optional": true, "type": "number", "description": "Automatically detect SLB Config", "format": "flag"}
    :param enable_list: {"minItems": 1, "items": {"type": "enable"}, "uniqueItems": true, "array": [{"required": ["type"], "properties": {"type": {"optional": false, "enum": ["controller", "device"], "type": "string", "description": "'controller': Enable/Disable GSLB protocol as GSLB controller; 'device': Enable/Disable GSLB protocol as site device; ", "format": "enum"}}}], "type": "array", "$ref": "/axapi/v3/gslb/protocol/enable/{type}"}
    :param status_interval: {"description": "Specify GSLB Message Protocol update period (The GSLB Protocol update interval (seconds), default is 30)", "format": "number", "type": "number", "maximum": 1800, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/protocol`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "protocol"
        self.a10_url="/axapi/v3/gslb/protocol"
        self.DeviceProxy = ""
        self.use_mgmt_port = ""
        self.limit = {}
        self.ping_site = ""
        self.auto_detect = ""
        self.enable_list = []
        self.status_interval = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class ManagementAddress(A10BaseClass):
    
    """Class Description::
    Configure lldp management address.

    Class management-address supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ipv6_addr_list: {"minItems": 1, "items": {"type": "ipv6-addr"}, "uniqueItems": true, "array": [{"required": ["ipv6"], "properties": {"interface-ipv6": {"type": "object", "properties": {"ipv6-ve": {"description": "configure lldp management-address interface ve (lldp management-address interface port number)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}, "ipv6-eth": {"type": "number", "description": "configure lldp management-address interface ethernet (lldp management-address interface port number)", "format": "interface"}, "ipv6-mgmt": {"default": 0, "type": "number", "description": "configure lldp management-address interface management", "format": "flag"}}}, "ipv6": {"optional": false, "type": "string", "description": "Configure lldp management-address, subtype is ipv6 (lldp management-address ipv6 address)", "format": "ipv6-address"}}}], "type": "array", "$ref": "/axapi/v3/network/lldp/management-address/ipv6-addr/{ipv6}"}
    :param ipv4_addr_list: {"minItems": 1, "items": {"type": "ipv4-addr"}, "uniqueItems": true, "array": [{"required": ["ipv4"], "properties": {"ipv4": {"optional": false, "type": "string", "description": "Configure lldp management-address, subtype is ipv4 (lldp management-address ipv4 address)", "format": "ipv4-address"}, "interface-ipv4": {"type": "object", "properties": {"ipv4-eth": {"type": "number", "description": "configure lldp management-address interface ethernet (lldp management-address interface port number)", "format": "interface"}, "ipv4-mgmt": {"default": 0, "type": "number", "description": "configure lldp management-address interface management", "format": "flag"}, "ipv4-ve": {"description": "configure lldp management-address interface ve (lldp management-address interface port number)", "minimum": 2, "type": "number", "maximum": 4094, "format": "number"}}}}}], "type": "array", "$ref": "/axapi/v3/network/lldp/management-address/ipv4-addr/{ipv4}"}
    :param dns_list: {"minItems": 1, "items": {"type": "dns"}, "uniqueItems": true, "array": [{"required": ["dns"], "properties": {"interface": {"type": "object", "properties": {"ethernet": {"not-list": ["ve", "management"], "type": "number", "description": "configure lldp management-address interface ethernet (lldp management-address interface port number)", "format": "interface"}, "management": {"default": 0, "not-list": ["ethernet", "ve"], "type": "number", "description": "configure lldp management-address interface management", "format": "flag"}, "ve": {"description": "configure lldp management-address interface management (lldp management-address interface port number)", "format": "number", "not-list": ["ethernet", "management"], "maximum": 4094, "minimum": 2, "type": "number"}}}, "dns": {"description": "Configure lldp management-address, subtype is dns (lldp management-address dns address)", "format": "string", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}}}], "type": "array", "$ref": "/axapi/v3/network/lldp/management-address/dns/{dns}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/network/lldp/management-address`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "management-address"
        self.a10_url="/axapi/v3/network/lldp/management-address"
        self.DeviceProxy = ""
        self.ipv6_addr_list = []
        self.ipv4_addr_list = []
        self.dns_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class EntryList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nat_end_port: {"type": "number", "format": "number"}
    :param inside_start_port: {"type": "number", "format": "number"}
    :param nat_address: {"type": "string", "format": "ipv4-address"}
    :param inside_end_port: {"type": "number", "format": "number"}
    :param nat_start_port: {"type": "number", "format": "number"}
    :param inside_address: {"type": "string", "format": "ipv4-address"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "entry-list"
        self.DeviceProxy = ""
        self.nat_end_port = ""
        self.inside_start_port = ""
        self.nat_address = ""
        self.inside_end_port = ""
        self.nat_start_port = ""
        self.inside_address = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param entry_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nat-end-port": {"type": "number", "format": "number"}, "inside-start-port": {"type": "number", "format": "number"}, "nat-address": {"type": "string", "format": "ipv4-address"}, "inside-end-port": {"type": "number", "format": "number"}, "nat-start-port": {"type": "number", "format": "number"}, "optional": true, "inside-address": {"type": "string", "format": "ipv4-address"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.entry_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class PortReservationEntries(A10BaseClass):
    
    """Class Description::
    Operational Status for the object port-reservation-entries.

    Class port-reservation-entries supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/lsn/port-reservation-entries/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "port-reservation-entries"
        self.a10_url="/axapi/v3/cgnv6/lsn/port-reservation-entries/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class LogoCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param logo: {"minLength": 1, "maxLength": 63, "type": "string", "description": "Specify logo image filename", "format": "string-rlx"}
    :param height: {"description": "Specify logo image height", "minimum": 50, "type": "number", "maximum": 400, "format": "number"}
    :param width: {"description": "Specify logo image width", "minimum": 50, "type": "number", "maximum": 400, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "logo-cfg"
        self.DeviceProxy = ""
        self.logo = ""
        self.height = ""
        self.width = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Portal(A10BaseClass):
    
    """Class Description::
    Authentication portal configuration.

    Class portal supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param name: {"optional": false, "enum": ["default-portal"], "type": "string", "description": "'default-portal': Default portal configuration; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/authentication/portal/{name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "portal"
        self.a10_url="/axapi/v3/aam/authentication/portal/{name}"
        self.DeviceProxy = ""
        self.logon_fail = {}
        self.logon = {}
        self.logo_cfg = {}
        self.name = ""
        self.change_password = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class LicenseManager(A10BaseClass):
    
    """Class Description::
    Configure license manager.

    Class license-manager supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param reminder_list: {"minItems": 1, "items": {"type": "reminder"}, "uniqueItems": true, "array": [{"required": ["reminder-value"], "properties": {"reminder-value": {"description": "Configure reminder for grace time (Hour)", "format": "number", "type": "number", "maximum": 1000000, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/license-manager/reminder/{reminder-value}"}
    :param bandwidth_base: {"description": "Configure feature bandwidth base (Mb)", "format": "number", "type": "number", "maximum": 102400, "minimum": 10, "optional": true}
    :param use_mgmt_port: {"description": "Use management port to connect license server", "partition-visibility": "shared", "default": 0, "type": "number", "format": "flag", "optional": true}
    :param interval: {"description": "Configure interval profile (1 monthly, 2 daily, 3 hourly)", "format": "number", "type": "number", "maximum": 3, "minimum": 1, "optional": true}
    :param sn: {"description": "serial number", "format": "string", "minLength": 1, "optional": true, "maxLength": 63, "type": "string"}
    :param host_list: {"minItems": 1, "items": {"type": "host"}, "uniqueItems": true, "array": [{"required": ["host-ipv4"], "properties": {"host-ipv4": {"description": "license server ip address (length:1-31)", "format": "host", "minLength": 1, "optional": false, "maxLength": 31, "type": "string"}, "port": {"description": "Configure the license manager port, default is 443", "format": "number", "default": 443, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}}}], "type": "array", "$ref": "/axapi/v3/license-manager/host/{host-ipv4}"}
    :param bandwidth_unrestricted: {"default": 0, "optional": true, "type": "number", "description": "Set the bandwidth to maximum", "format": "flag"}
    :param instance_name: {"description": "Configure instance name [format: (string).(string).(string).(string)]", "format": "string", "minLength": 7, "optional": true, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/license-manager`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "license-manager"
        self.a10_url="/axapi/v3/license-manager"
        self.DeviceProxy = ""
        self.reminder_list = []
        self.bandwidth_base = ""
        self.use_mgmt_port = ""
        self.interval = ""
        self.overage = {}
        self.sn = ""
        self.host_list = []
        self.bandwidth_unrestricted = ""
        self.instance_name = ""
        self.connect = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Force(A10BaseClass):
    
    """Class Description::
    Unconditional write to Non-volatile Memory.

    Class force supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param all_partitions: {"type": "number", "description": "All partition configurations", "format": "flag"}
    :param name: {"description": "Local Configuration Profile Name", "format": "string", "minLength": "1", "optional": false, "maxLength": "31", "type": "string"}
    :param primary: {"type": "number", "description": "Write to default Primary Configuration", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/write/force`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "force"
        self.a10_url="/axapi/v3/write/force"
        self.DeviceProxy = ""
        self.all_partitions = ""
        self.name = ""
        self.primary = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Options(A10BaseClass):
    
    """Class Description::
    Partition specific overlay-tunnel configuration.

    Class options supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param nvgre_key_mode_lower24: {"default": 0, "optional": true, "type": "number", "description": "Use the lower 24-bits of the GRE key as the VSID", "format": "flag"}
    :param tcp_mss_adjust_disable: {"default": 0, "optional": true, "type": "number", "description": "Disable TCP MSS adjustment in SYN packet for tunnels", "format": "flag"}
    :param gateway_mac: {"optional": true, "type": "string", "description": "MAC to be used with Gateway segment Id (MAC Address for the Gateway segment)", "format": "mac-address"}
    :param ip_dscp_preserve: {"default": 0, "optional": true, "type": "number", "description": "Copy DSCP bits from inner IP to outer IP header", "format": "flag"}
    :param nvgre_disable_flow_id: {"default": 0, "optional": true, "type": "number", "description": "Disable Flow-ID computation for NVGRE", "format": "flag"}
    :param vxlan_dest_port: {"description": "VXLAN UDP Destination Port (UDP Port Number (default 4789))", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/overlay-tunnel/options`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "options"
        self.a10_url="/axapi/v3/overlay-tunnel/options"
        self.DeviceProxy = ""
        self.nvgre_key_mode_lower24 = ""
        self.tcp_mss_adjust_disable = ""
        self.gateway_mac = ""
        self.ip_dscp_preserve = ""
        self.nvgre_disable_flow_id = ""
        self.vxlan_dest_port = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Udp(A10BaseClass):
    
    """Class Description::
    Configure UDP parameters for stateful firewall.

    Class udp supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param stun_timeout_list: {"minItems": 1, "items": {"type": "stun-timeout"}, "uniqueItems": true, "array": [{"required": ["port", "port-end"], "properties": {"stun-timeout-val-port-range": {"description": "STUN timeout (default: 2 minutes)", "format": "number", "default": 2, "optional": true, "maximum": 60, "minimum": 0, "type": "number"}, "port": {"description": "Single Destination Port or Port Range Start", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "port-end": {"description": "Port Range End", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/stateful-firewall/udp/stun-timeout/{port}+{port-end}"}
    :param idle_timeout_list: {"minItems": 1, "items": {"type": "idle-timeout"}, "uniqueItems": true, "array": [{"required": ["port", "port-end"], "properties": {"idle-timeout-val-port-range": {"description": "Idle timeout for IPv4 and IPv6 TCP established sessions (Idle timeout for IPv4 and IPv6 TCP established sessions (default: 300 seconds))", "format": "number", "default": 300, "optional": true, "maximum": 3780, "minimum": 60, "not": "fast", "type": "number"}, "port": {"description": "Single Destination Port or Port Range Start", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}, "fast": {"description": "Fast aging for idle sessions", "format": "flag", "default": 0, "optional": true, "not": "idle-timeout-val-port-range", "type": "number"}, "port-end": {"description": "Port Range End", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": false}}}], "type": "array", "$ref": "/axapi/v3/cgnv6/stateful-firewall/udp/idle-timeout/{port}+{port-end}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/cgnv6/stateful-firewall/udp`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "udp"
        self.a10_url="/axapi/v3/cgnv6/stateful-firewall/udp"
        self.DeviceProxy = ""
        self.stun_timeout_list = []
        self.idle_timeout_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Ospf(A10BaseClass):
    
    """Class Description::
    Open Shortest Path First for IPv4 (OSPF).

    Class ospf supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param ospf_ip_list: {"minItems": 1, "items": {"type": "ospf-ip"}, "uniqueItems": true, "array": [{"required": ["ip-addr"], "properties": {"dead-interval": {"description": "Interval after which a neighbor is declared dead (Seconds)", "format": "number", "default": 40, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication-key": {"description": "Authentication password (key) (The OSPF password (key))", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 8, "type": "string"}, "mtu-ignore": {"default": 0, "optional": true, "type": "number", "description": "Ignores the MTU in DBD packets", "format": "flag"}, "priority": {"description": "Router priority", "format": "number", "default": 1, "optional": true, "maximum": 255, "minimum": 0, "type": "number"}, "transmit-delay": {"description": "Link state transmit delay (Seconds)", "format": "number", "default": 1, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "value": {"optional": true, "enum": ["message-digest", "null"], "type": "string", "description": "'message-digest': Use message-digest authentication; 'null': Use no authentication; ", "format": "enum"}, "hello-interval": {"description": "Time between HELLO packets (Seconds)", "format": "number", "default": 10, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "authentication": {"default": 0, "optional": true, "type": "number", "description": "Enable authentication", "format": "flag"}, "cost": {"description": "Interface cost", "format": "number", "type": "number", "maximum": 65535, "minimum": 1, "optional": true}, "database-filter": {"optional": true, "enum": ["all"], "type": "string", "description": "'all': Filter all LSA; ", "format": "enum"}, "ip-addr": {"optional": false, "type": "string", "description": "Address of interface", "format": "ipv4-address"}, "retransmit-interval": {"description": "Time between retransmitting lost link state advertisements (Seconds)", "format": "number", "default": 5, "optional": true, "maximum": 65535, "minimum": 1, "type": "number"}, "message-digest-cfg": {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"md5-value": {"minLength": 1, "maxLength": 16, "type": "string", "description": "The OSPF password (1-16)", "format": "password"}, "message-digest-key": {"description": "Message digest authentication password (key) (Key id)", "minimum": 1, "type": "number", "maximum": 255, "format": "number"}, "optional": true, "encrypted": {"type": "encrypted", "description": "Do NOT use this option manually. (This is an A10 reserved keyword.) (The ENCRYPTED password string)", "format": "encrypted"}}}]}, "out": {"default": 0, "optional": true, "type": "number", "description": "Outgoing LSA", "format": "flag"}}}], "type": "array", "$ref": "/axapi/v3/interface/ve/{ifnum}/ip/ospf/ospf-ip/{ip-addr}"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/ve/{ifnum}/ip/ospf`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ospf"
        self.a10_url="/axapi/v3/interface/ve/{ifnum}/ip/ospf"
        self.DeviceProxy = ""
        self.ospf_ip_list = []
        self.ospf_global = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class DnssecDs(A10BaseClass):
    
    """    :param action: {"optional": true, "enum": ["create", "import", "export", "copy", "rename", "check", "replace", "delete"], "type": "string", "description": "'create': create; 'import': import; 'export': export; 'copy': copy; 'rename': rename; 'check': check; 'replace': replace; 'delete': delete; ", "format": "enum"}
    :param dst_file: {"description": "destination file name for copy and rename action", "format": "string", "minLength": 1, "optional": true, "maxLength": 32, "type": "string"}
    :param file_handle: {"description": "full path of the uploaded file", "format": "string-rlx", "minLength": 1, "optional": true, "maxLength": 255, "type": "string"}
    :param file: {"description": "dnssec ds local file name", "format": "string", "minLength": 1, "optional": true, "maxLength": 127, "type": "string"}
    :param size: {"optional": true, "type": "number", "description": "dnssec ds file size in byte", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    dnssec ds file information and management commands.

    Class dnssec-ds supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/file/dnssec-ds`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "dnssec-ds"
        self.a10_url="/axapi/v3/file/dnssec-ds"
        self.DeviceProxy = ""
        self.action = ""
        self.dst_file = ""
        self.file_handle = ""
        self.A10WW_file = ""
        self.size = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class AddressList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv4_address: {"type": "string", "description": "IP address", "format": "ipv4-address"}
    :param ipv4_netmask: {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "address-list"
        self.DeviceProxy = ""
        self.ipv4_address = ""
        self.ipv4_netmask = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ip(A10BaseClass):
    
    """Class Description::
    Global IP configuration subcommands.

    Class ip supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param address_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"ipv4-address": {"type": "string", "description": "IP address", "format": "ipv4-address"}, "optional": true, "ipv4-netmask": {"type": "string", "description": "IP subnet mask", "format": "ipv4-netmask"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/interface/loopback/{ifnum}/ip`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "ip"
        self.a10_url="/axapi/v3/interface/loopback/{ifnum}/ip"
        self.DeviceProxy = ""
        self.address_list = []
        self.ospf = {}
        self.rip = {}
        self.router = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class GeolocList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param tomask: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param hits: {"type": "number", "format": "number"}
    :param from: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param subcnt: {"type": "number", "format": "number"}
    :param last: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param type: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "geoloc-list"
        self.DeviceProxy = ""
        self.tomask = ""
        self.hits = ""
        self.A10WW_from = ""
        self.subcnt = ""
        self.last = ""
        self.A10WW_type = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param ipv6rangestrt: {"type": "string", "format": "ipv6-address"}
    :param pol_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param total_geolocs: {"type": "number", "format": "number"}
    :param iprangestrt: {"type": "string", "format": "ipv4-address"}
    :param filter4: {"enum": ["ip", "ipv6", "ipstat", "ipv6stat"], "type": "string", "format": "enum"}
    :param iprangeend: {"type": "string", "format": "ipv4-address"}
    :param filter1: {"enum": ["directory", "statistics", "global"], "type": "string", "format": "enum"}
    :param filter3: {"enum": ["directory", "statistics", "global"], "type": "string", "format": "enum"}
    :param filter2: {"enum": ["directory", "statistics", "global"], "type": "string", "format": "enum"}
    :param geo_name: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param geoloc_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"tomask": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "hits": {"type": "number", "format": "number"}, "from": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "subcnt": {"type": "number", "format": "number"}, "optional": true, "last": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "type": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "name": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.ipv6rangestrt = ""
        self.pol_name = ""
        self.total_geolocs = ""
        self.iprangestrt = ""
        self.filter4 = ""
        self.iprangeend = ""
        self.filter1 = ""
        self.filter3 = ""
        self.filter2 = ""
        self.geo_name = ""
        self.geoloc_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Geoloc(A10BaseClass):
    
    """Class Description::
    Operational Status for the object geoloc.

    Class geoloc supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/geoloc/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "geoloc"
        self.a10_url="/axapi/v3/gslb/geoloc/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param Req: {"description": "Request", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "8"}
    :param Req_Auth: {"description": "Request Matching Authentication Template", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "8"}
    :param Req_Allow: {"description": "Request Allowed", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "8"}
    :param Req_Skip: {"description": "Request Skipped", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "8"}
    :param Error: {"description": "Error", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "8"}
    :param Req_Reject: {"description": "Request Rejected", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "8"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.Req = ""
        self.Req_Auth = ""
        self.Req_Allow = ""
        self.Req_Skip = ""
        self.Error = ""
        self.Req_Reject = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class AaaPolicy(A10BaseClass):
    
    """Class Description::
    Statistics for the object aaa-policy.

    Class aaa-policy supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param aaa_rule_list: {"minItems": 1, "items": {"type": "aaa-rule"}, "uniqueItems": true, "array": [{"required": ["index"], "properties": {}}], "type": "array", "$ref": "/axapi/v3/aam/aaa-policy/{name}/aaa-rule/{index}"}
    :param name: {"description": "Specify AAA policy name", "format": "string", "minLength": 1, "oid": "1001", "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/aam/aaa-policy/{name}/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "name"]

        self.b_key = "aaa-policy"
        self.a10_url="/axapi/v3/aam/aaa-policy/{name}/stats"
        self.DeviceProxy = ""
        self.aaa_rule_list = []
        self.stats = {}
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SessionList(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param session_id: {"type": "number", "format": "number"}
    :param connection_succeeded: {"type": "number", "format": "number"}
    :param sessions_dropped: {"type": "number", "format": "number"}
    :param retry: {"type": "number", "format": "number"}
    :param update_packet_sent: {"type": "number", "format": "number"}
    :param open_packet_received: {"type": "number", "format": "number"}
    :param protocol_info: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param keepalive_packet_received: {"type": "number", "format": "number"}
    :param update_packet_received: {"type": "number", "format": "number"}
    :param notify_packet_sent: {"type": "number", "format": "number"}
    :param open_packet_sent: {"type": "number", "format": "number"}
    :param state: {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}
    :param keepalive_packet_sent: {"type": "number", "format": "number"}
    :param message_header_error: {"type": "number", "format": "number"}
    :param open_session_failed: {"type": "number", "format": "number"}
    :param notify_packet_received: {"type": "number", "format": "number"}
    :param open_session_succeeded: {"type": "number", "format": "number"}
    :param connection_failed: {"type": "number", "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "session-list"
        self.DeviceProxy = ""
        self.session_id = ""
        self.connection_succeeded = ""
        self.sessions_dropped = ""
        self.retry = ""
        self.update_packet_sent = ""
        self.open_packet_received = ""
        self.protocol_info = ""
        self.keepalive_packet_received = ""
        self.update_packet_received = ""
        self.notify_packet_sent = ""
        self.open_packet_sent = ""
        self.state = ""
        self.keepalive_packet_sent = ""
        self.message_header_error = ""
        self.open_session_failed = ""
        self.notify_packet_received = ""
        self.open_session_succeeded = ""
        self.connection_failed = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Oper(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param session_list: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"session-id": {"type": "number", "format": "number"}, "connection-succeeded": {"type": "number", "format": "number"}, "sessions-dropped": {"type": "number", "format": "number"}, "retry": {"type": "number", "format": "number"}, "update-packet-sent": {"type": "number", "format": "number"}, "open-packet-received": {"type": "number", "format": "number"}, "protocol-info": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "keepalive-packet-received": {"type": "number", "format": "number"}, "update-packet-received": {"type": "number", "format": "number"}, "notify-packet-sent": {"type": "number", "format": "number"}, "open-packet-sent": {"type": "number", "format": "number"}, "state": {"minLength": 1, "maxLength": 63, "type": "string", "format": "string"}, "keepalive-packet-sent": {"type": "number", "format": "number"}, "message-header-error": {"type": "number", "format": "number"}, "open-session-failed": {"type": "number", "format": "number"}, "notify-packet-received": {"type": "number", "format": "number"}, "optional": true, "open-session-succeeded": {"type": "number", "format": "number"}, "connection-failed": {"type": "number", "format": "number"}}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "oper"
        self.DeviceProxy = ""
        self.session_list = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Protocol(A10BaseClass):
    
    """Class Description::
    Operational Status for the object protocol.

    Class protocol supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/protocol/oper`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "protocol"
        self.a10_url="/axapi/v3/gslb/protocol/oper"
        self.DeviceProxy = ""
        self.oper = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class SharedCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param shared: {"default": 0, "not": "name", "type": "number", "description": "Shared partition", "format": "flag"}
    :param vrid: {"default": 0, "type": "number", "description": "VRRP-A id", "format": "flag"}
    :param vrid_value: {"description": "Specify ha VRRP-A vrid", "minimum": 0, "type": "number", "maximum": 31, "format": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "shared-cfg"
        self.DeviceProxy = ""
        self.shared = ""
        self.vrid = ""
        self.vrid_value = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NameCfg(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param vrid_value: {"description": "Specify ha VRRP-A vrid", "minimum": 0, "type": "number", "maximum": 7, "format": "number"}
    :param vrid: {"default": 0, "type": "number", "description": "VRRP-A id", "format": "flag"}
    :param name: {"description": "Partition name", "format": "string", "minLength": 1, "maxLength": 14, "not": "shared", "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "name-cfg"
        self.DeviceProxy = ""
        self.vrid_value = ""
        self.vrid = ""
        self.name = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Partition(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param partition: {"default": 0, "type": "number", "description": "Partition name", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "partition"
        self.DeviceProxy = ""
        self.shared_cfg = {}
        self.name_cfg = {}
        self.partition = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class VridLead(A10BaseClass):
    
    """Class Description::
    Define a vrid-lead.

    Class vrid-lead supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param vrid_lead_str: {"description": "VRRP-A VRID leader name", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/vrrp-a/vrid-lead/{vrid_lead_str}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "vrid_lead_str"]

        self.b_key = "vrid-lead"
        self.a10_url="/axapi/v3/vrrp-a/vrid-lead/{vrid_lead_str}"
        self.DeviceProxy = ""
        self.vrid_lead_str = ""
        self.partition = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Stats(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param REQ_50u: {"description": "Rsp time less than 50u", "format": "counter", "type": "number", "oid": "72", "optional": true, "size": "2"}
    :param ws_server_switch: {"description": "WS Server Pkts", "format": "counter", "type": "number", "oid": "69", "optional": true, "size": "2"}
    :param REQ_50m: {"description": "Rsp time less than 5m", "format": "counter", "type": "number", "oid": "81", "optional": true, "size": "2"}
    :param status_450: {"description": "Status code 450", "format": "counter", "type": "number", "oid": "46", "optional": true, "size": "2"}
    :param REQ_500m: {"description": "Rsp time less than 500m", "format": "counter", "type": "number", "oid": "84", "optional": true, "size": "2"}
    :param status_510: {"description": "Status code 510", "format": "counter", "type": "number", "oid": "58", "optional": true, "size": "2"}
    :param ws_handshake_request: {"description": "WS Handshake Req", "format": "counter", "type": "number", "oid": "66", "optional": true, "size": "2"}
    :param status_207: {"description": "Status code 207", "format": "counter", "type": "number", "oid": "8", "optional": true, "size": "2"}
    :param status_206: {"description": "Status code 206", "format": "counter", "type": "number", "oid": "7", "optional": true, "size": "2"}
    :param status_205: {"description": "Status code 205", "format": "counter", "type": "number", "oid": "6", "optional": true, "size": "2"}
    :param status_204: {"description": "Status code 204", "format": "counter", "type": "number", "oid": "5", "optional": true, "size": "2"}
    :param status_203: {"description": "Status code 203", "format": "counter", "type": "number", "oid": "4", "optional": true, "size": "2"}
    :param status_202: {"description": "Status code 202", "format": "counter", "type": "number", "oid": "3", "optional": true, "size": "2"}
    :param status_201: {"description": "Status code 201", "format": "counter", "type": "number", "oid": "2", "optional": true, "size": "2"}
    :param status_200: {"description": "Status code 200", "format": "counter", "type": "number", "oid": "1", "optional": true, "size": "2"}
    :param ws_client_switch: {"description": "WS Client Pkts", "format": "counter", "type": "number", "oid": "68", "optional": true, "size": "2"}
    :param status_406: {"description": "Status code 406", "format": "counter", "type": "number", "oid": "27", "optional": true, "size": "2"}
    :param REQ_20u: {"description": "Rsp time less than 20u", "format": "counter", "type": "number", "oid": "71", "optional": true, "size": "2"}
    :param status_4xx: {"description": "status code 4XX", "format": "counter", "type": "number", "oid": "62", "optional": true, "size": "2"}
    :param status_3xx: {"description": "status code 3XX", "format": "counter", "type": "number", "oid": "61", "optional": true, "size": "2"}
    :param REQ_200u: {"description": "Rsp time less than 200u", "format": "counter", "type": "number", "oid": "74", "optional": true, "size": "2"}
    :param REQ_100m: {"description": "Rsp time less than 100m", "format": "counter", "type": "number", "oid": "82", "optional": true, "size": "2"}
    :param REQ_5m: {"description": "Rsp time less than 5m", "format": "counter", "type": "number", "oid": "78", "optional": true, "size": "2"}
    :param REQ_100u: {"description": "Rsp time less than 100u", "format": "counter", "type": "number", "oid": "73", "optional": true, "size": "2"}
    :param REQ_5s: {"description": "Rsp time less than 5s", "format": "counter", "type": "number", "oid": "87", "optional": true, "size": "2"}
    :param REQ_20m: {"description": "Rsp time less than 20m", "format": "counter", "type": "number", "oid": "80", "optional": true, "size": "2"}
    :param REQ_500u: {"description": "Rsp time less than 500u", "format": "counter", "type": "number", "oid": "75", "optional": true, "size": "2"}
    :param REQ_2s: {"description": "Rsp time less than 2s", "format": "counter", "type": "number", "oid": "86", "optional": true, "size": "2"}
    :param REQ_200m: {"description": "Rsp time less than 200m", "format": "counter", "type": "number", "oid": "83", "optional": true, "size": "2"}
    :param status_307: {"description": "Status code 307", "format": "counter", "type": "number", "oid": "20", "optional": true, "size": "2"}
    :param status_304: {"description": "Status code 304", "format": "counter", "type": "number", "oid": "17", "optional": true, "size": "2"}
    :param status_305: {"description": "Status code 305", "format": "counter", "type": "number", "oid": "18", "optional": true, "size": "2"}
    :param status_302: {"description": "Status code 302", "format": "counter", "type": "number", "oid": "15", "optional": true, "size": "2"}
    :param status_303: {"description": "Status code 303", "format": "counter", "type": "number", "oid": "16", "optional": true, "size": "2"}
    :param status_300: {"description": "Status code 300", "format": "counter", "type": "number", "oid": "13", "optional": true, "size": "2"}
    :param status_301: {"description": "Status code 301", "format": "counter", "type": "number", "oid": "14", "optional": true, "size": "2"}
    :param REQ_10u: {"description": "Rsp time less than 10u", "format": "counter", "type": "number", "oid": "70", "optional": true, "size": "2"}
    :param REQ_10m: {"description": "Rsp time less than 10m", "format": "counter", "type": "number", "oid": "79", "optional": true, "size": "2"}
    :param status_306: {"description": "Status code 306", "format": "counter", "type": "number", "oid": "19", "optional": true, "size": "2"}
    :param status_412: {"description": "Status code 412", "format": "counter", "type": "number", "oid": "33", "optional": true, "size": "2"}
    :param status_413: {"description": "Status code 413", "format": "counter", "type": "number", "oid": "34", "optional": true, "size": "2"}
    :param status_410: {"description": "Status code 410", "format": "counter", "type": "number", "oid": "31", "optional": true, "size": "2"}
    :param status_411: {"description": "Status code 411", "format": "counter", "type": "number", "oid": "32", "optional": true, "size": "2"}
    :param status_416: {"description": "Status code 416", "format": "counter", "type": "number", "oid": "37", "optional": true, "size": "2"}
    :param status_417: {"description": "Status code 417", "format": "counter", "type": "number", "oid": "38", "optional": true, "size": "2"}
    :param status_414: {"description": "Status code 414", "format": "counter", "type": "number", "oid": "35", "optional": true, "size": "2"}
    :param status_415: {"description": "Status code 415", "format": "counter", "type": "number", "oid": "36", "optional": true, "size": "2"}
    :param status_418: {"description": "Status code 418", "format": "counter", "type": "number", "oid": "39", "optional": true, "size": "2"}
    :param status_unknown: {"description": "Status code unknown", "format": "counter", "type": "number", "oid": "65", "optional": true, "size": "2"}
    :param status_100: {"description": "Status code 100", "format": "counter", "type": "number", "oid": "9", "optional": true, "size": "2"}
    :param status_101: {"description": "Status code 101", "format": "counter", "type": "number", "oid": "10", "optional": true, "size": "2"}
    :param status_102: {"description": "Status code 102", "format": "counter", "type": "number", "oid": "11", "optional": true, "size": "2"}
    :param status_103: {"description": "Status code 103", "format": "counter", "type": "number", "oid": "12", "optional": true, "size": "2"}
    :param REQ_2m: {"description": "Rsp time less than 2m", "format": "counter", "type": "number", "oid": "77", "optional": true, "size": "2"}
    :param ws_handshake_success: {"description": "WS Handshake Res", "format": "counter", "type": "number", "oid": "67", "optional": true, "size": "2"}
    :param status_504_ax: {"description": "Status code 504 AX-gen", "format": "counter", "type": "number", "oid": "52", "optional": true, "size": "2"}
    :param status_6xx: {"description": "status code 6XX", "format": "counter", "type": "number", "oid": "64", "optional": true, "size": "2"}
    :param status_5xx: {"description": "status code 5XX", "format": "counter", "type": "number", "oid": "63", "optional": true, "size": "2"}
    :param status_401: {"description": "Status code 401", "format": "counter", "type": "number", "oid": "22", "optional": true, "size": "2"}
    :param status_400: {"description": "Status code 400", "format": "counter", "type": "number", "oid": "21", "optional": true, "size": "2"}
    :param status_403: {"description": "Status code 403", "format": "counter", "type": "number", "oid": "24", "optional": true, "size": "2"}
    :param status_402: {"description": "Status code 402", "format": "counter", "type": "number", "oid": "23", "optional": true, "size": "2"}
    :param status_405: {"description": "Status code 405", "format": "counter", "type": "number", "oid": "26", "optional": true, "size": "2"}
    :param status_404: {"description": "Status code 404", "format": "counter", "type": "number", "oid": "25", "optional": true, "size": "2"}
    :param status_407: {"description": "Status code 407", "format": "counter", "type": "number", "oid": "28", "optional": true, "size": "2"}
    :param status_2xx: {"description": "status code 2XX", "format": "counter", "type": "number", "oid": "60", "optional": true, "size": "2"}
    :param status_409: {"description": "Status code 409", "format": "counter", "type": "number", "oid": "30", "optional": true, "size": "2"}
    :param status_408: {"description": "Status code 408", "format": "counter", "type": "number", "oid": "29", "optional": true, "size": "2"}
    :param REQ_1m: {"description": "Rsp time less than 1m", "format": "counter", "type": "number", "oid": "76", "optional": true, "size": "2"}
    :param REQ_1s: {"description": "Rsp time less than 1s", "format": "counter", "type": "number", "oid": "85", "optional": true, "size": "2"}
    :param status_1xx: {"description": "status code 1XX", "format": "counter", "type": "number", "oid": "59", "optional": true, "size": "2"}
    :param status_423: {"description": "Status code 423", "format": "counter", "type": "number", "oid": "41", "optional": true, "size": "2"}
    :param status_422: {"description": "Status code 422", "format": "counter", "type": "number", "oid": "40", "optional": true, "size": "2"}
    :param status_426: {"description": "Status code 426", "format": "counter", "type": "number", "oid": "44", "optional": true, "size": "2"}
    :param status_425: {"description": "Status code 425", "format": "counter", "type": "number", "oid": "43", "optional": true, "size": "2"}
    :param status_424: {"description": "Status code 424", "format": "counter", "type": "number", "oid": "42", "optional": true, "size": "2"}
    :param status_508: {"description": "Status code 508", "format": "counter", "type": "number", "oid": "56", "optional": true, "size": "2"}
    :param status_509: {"description": "Status code 509", "format": "counter", "type": "number", "oid": "57", "optional": true, "size": "2"}
    :param REQ_OVER_5s: {"description": "Rsp time greater than equal to 5s", "format": "counter", "type": "number", "oid": "88", "optional": true, "size": "2"}
    :param status_500: {"description": "Status code 500", "format": "counter", "type": "number", "oid": "47", "optional": true, "size": "2"}
    :param status_501: {"description": "Status code 501", "format": "counter", "type": "number", "oid": "48", "optional": true, "size": "2"}
    :param status_502: {"description": "Status code 502", "format": "counter", "type": "number", "oid": "49", "optional": true, "size": "2"}
    :param status_503: {"description": "Status code 503", "format": "counter", "type": "number", "oid": "50", "optional": true, "size": "2"}
    :param status_504: {"description": "Status code 504", "format": "counter", "type": "number", "oid": "51", "optional": true, "size": "2"}
    :param status_505: {"description": "Status code 505", "format": "counter", "type": "number", "oid": "53", "optional": true, "size": "2"}
    :param status_506: {"description": "Status code 506", "format": "counter", "type": "number", "oid": "54", "optional": true, "size": "2"}
    :param status_507: {"description": "Status code 507", "format": "counter", "type": "number", "oid": "55", "optional": true, "size": "2"}
    :param status_449: {"description": "Status code 449", "format": "counter", "type": "number", "oid": "45", "optional": true, "size": "2"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "stats"
        self.DeviceProxy = ""
        self.REQ_50u = ""
        self.ws_server_switch = ""
        self.REQ_50m = ""
        self.status_450 = ""
        self.REQ_500m = ""
        self.status_510 = ""
        self.ws_handshake_request = ""
        self.status_207 = ""
        self.status_206 = ""
        self.status_205 = ""
        self.status_204 = ""
        self.status_203 = ""
        self.status_202 = ""
        self.status_201 = ""
        self.status_200 = ""
        self.ws_client_switch = ""
        self.status_406 = ""
        self.REQ_20u = ""
        self.status_4xx = ""
        self.status_3xx = ""
        self.REQ_200u = ""
        self.REQ_100m = ""
        self.REQ_5m = ""
        self.REQ_100u = ""
        self.REQ_5s = ""
        self.REQ_20m = ""
        self.REQ_500u = ""
        self.REQ_2s = ""
        self.REQ_200m = ""
        self.status_307 = ""
        self.status_304 = ""
        self.status_305 = ""
        self.status_302 = ""
        self.status_303 = ""
        self.status_300 = ""
        self.status_301 = ""
        self.REQ_10u = ""
        self.REQ_10m = ""
        self.status_306 = ""
        self.status_412 = ""
        self.status_413 = ""
        self.status_410 = ""
        self.status_411 = ""
        self.status_416 = ""
        self.status_417 = ""
        self.status_414 = ""
        self.status_415 = ""
        self.status_418 = ""
        self.status_unknown = ""
        self.status_100 = ""
        self.status_101 = ""
        self.status_102 = ""
        self.status_103 = ""
        self.REQ_2m = ""
        self.ws_handshake_success = ""
        self.status_504_ax = ""
        self.status_6xx = ""
        self.status_5xx = ""
        self.status_401 = ""
        self.status_400 = ""
        self.status_403 = ""
        self.status_402 = ""
        self.status_405 = ""
        self.status_404 = ""
        self.status_407 = ""
        self.status_2xx = ""
        self.status_409 = ""
        self.status_408 = ""
        self.REQ_1m = ""
        self.REQ_1s = ""
        self.status_1xx = ""
        self.status_423 = ""
        self.status_422 = ""
        self.status_426 = ""
        self.status_425 = ""
        self.status_424 = ""
        self.status_508 = ""
        self.status_509 = ""
        self.REQ_OVER_5s = ""
        self.status_500 = ""
        self.status_501 = ""
        self.status_502 = ""
        self.status_503 = ""
        self.status_504 = ""
        self.status_505 = ""
        self.status_506 = ""
        self.status_507 = ""
        self.status_449 = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Http_Vport(A10BaseClass):
    
    """Class Description::
    Statistics for the object http_vport.

    Class http_vport supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/counter/http-vport/stats`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "http_vport"
        self.a10_url="/axapi/v3/counter/http-vport/stats"
        self.DeviceProxy = ""
        self.stats = {}

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class MultipleFields(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param field: {"description": "Field index number (Index of Field)", "minimum": 1, "type": "number", "maximum": 64, "format": "number"}
    :param csv_type: {"enum": ["ip-from", "ip-to-mask", "continent", "country", "state", "city"], "type": "string", "description": "'ip-from': Beginning address of IP range or subnet; 'ip-to-mask': Ending address of IP range or Mask; 'continent': Continent; 'country': Country; 'state': State or province; 'city': City; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "multiple-fields"
        self.DeviceProxy = ""
        self.field = ""
        self.csv_type = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Csv(A10BaseClass):
    
    """Class Description::
    Specify csv template.

    Class csv supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param delim_char: {"description": "enter a delimiter character, default \",\"", "format": "string-rlx", "default": ",", "minLength": 1, "optional": true, "maxLength": 1, "not": "delim-num", "type": "string"}
    :param multiple_fields: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"field": {"description": "Field index number (Index of Field)", "minimum": 1, "type": "number", "maximum": 64, "format": "number"}, "optional": true, "csv-type": {"enum": ["ip-from", "ip-to-mask", "continent", "country", "state", "city"], "type": "string", "description": "'ip-from': Beginning address of IP range or subnet; 'ip-to-mask': Ending address of IP range or Mask; 'continent': Continent; 'country': Country; 'state': State or province; 'city': City; ", "format": "enum"}}}]}
    :param ipv6_enable: {"default": 0, "optional": true, "type": "number", "description": "Support IPv6 IP ranges", "format": "flag"}
    :param csv_name: {"description": "Specify name of csv template", "format": "string", "minLength": 1, "optional": false, "maxLength": 63, "type": "string"}
    :param delim_num: {"description": "enter a delimiter number, default 44 (\",\")", "format": "number", "default": 44, "optional": true, "maximum": 255, "minimum": 0, "not": "delim-char", "type": "number"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/gslb/template/csv/{csv_name}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "csv_name"]

        self.b_key = "csv"
        self.a10_url="/axapi/v3/gslb/template/csv/{csv_name}"
        self.DeviceProxy = ""
        self.delim_char = ""
        self.multiple_fields = []
        self.ipv6_enable = ""
        self.csv_name = ""
        self.delim_num = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Key(A10BaseClass):
    
    """Class Description::
    Configure a key.

    Class key supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param key_number: {"description": "Key identifier number", "format": "number", "type": "number", "maximum": 255, "minimum": 1, "optional": false}
    :param key_string: {"description": "Set key string (The key)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/key/{key_chain_flag}+{key_chain_name}/key/{key_number}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "key_number"]

        self.b_key = "key"
        self.a10_url="/axapi/v3/key/{key_chain_flag}+{key_chain_name}/key/{key_number}"
        self.DeviceProxy = ""
        self.key_number = ""
        self.key_string = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class NeighborPrefixLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nbr_prefix_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}
    :param nbr_prefix_list: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor-prefix-lists"
        self.DeviceProxy = ""
        self.nbr_prefix_list_direction = ""
        self.nbr_prefix_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class DistributeLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param distribute_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}
    :param distribute_list: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "distribute-lists"
        self.DeviceProxy = ""
        self.distribute_list_direction = ""
        self.distribute_list = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NeighborRouteMapLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param nbr_rmap_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}
    :param nbr_route_map: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor-route-map-lists"
        self.DeviceProxy = ""
        self.nbr_rmap_direction = ""
        self.nbr_route_map = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class NeighborFilterLists(A10BaseClass):
    
    """This class does not support CRUD Operations please use parent.

    :param filter_list: {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}
    :param filter_list_direction: {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        
        self.b_key = "neighbor-filter-lists"
        self.DeviceProxy = ""
        self.filter_list = ""
        self.filter_list_direction = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


class Ipv4Neighbor(A10BaseClass):
    
    """Class Description::
    Specify a peer-group neighbor router.

    Class ipv4-neighbor supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param maximum_prefix: {"description": "Maximum number of prefix accept from this peer (maximum no. of prefix limit (various depends on model))", "format": "number", "type": "number", "maximum": 65536, "minimum": 1, "optional": true}
    :param neighbor_prefix_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-prefix-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-prefix-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (Name of a prefix list)", "format": "string"}}}]}
    :param allowas_in_count: {"description": "Number of occurrences of AS number", "format": "number", "default": 3, "optional": true, "maximum": 10, "minimum": 1, "type": "number"}
    :param weight: {"description": "Set default weight for routes from this neighbor", "format": "number", "default": 0, "optional": true, "maximum": 65535, "minimum": 0, "type": "number"}
    :param peer_group_name: {"description": "Configure peer-group (peer-group name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param send_community_val: {"description": "'both': Send Standard and Extended Community attributes; 'none': Disable Sending Community attributes; 'standard': Send Standard Community attributes; 'extended': Send Extended Community attributes; ", "format": "enum", "default": "both", "type": "string", "enum": ["both", "none", "standard", "extended"], "optional": true}
    :param neighbor_ipv4: {"optional": false, "type": "string", "description": "Neighbor address", "format": "ipv4-address"}
    :param inbound: {"default": 0, "optional": true, "type": "number", "description": "Allow inbound soft reconfiguration for this neighbor", "format": "flag"}
    :param next_hop_self: {"default": 0, "optional": true, "type": "number", "description": "Disable the next hop calculation for this neighbor", "format": "flag"}
    :param maximum_prefix_thres: {"description": "threshold-value, 1 to 100 percent", "format": "number", "type": "number", "maximum": 100, "minimum": 1, "optional": true}
    :param route_map: {"description": "Route-map to specify criteria to originate default (route-map name)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param default_originate: {"default": 0, "optional": true, "type": "number", "description": "Originate default route to this neighbor", "format": "flag"}
    :param remove_private_as: {"default": 0, "optional": true, "type": "number", "description": "Remove private AS number from outbound updates", "format": "flag"}
    :param unsuppress_map: {"description": "Route-map to selectively unsuppress suppressed routes (Name of route map)", "format": "string", "minLength": 1, "optional": true, "maxLength": 128, "type": "string"}
    :param allowas_in: {"default": 0, "optional": true, "type": "number", "description": "Accept as-path with my AS present in it", "format": "flag"}
    :param activate: {"default": 0, "optional": true, "type": "number", "description": "Enable the Address Family for this Neighbor", "format": "flag"}
    :param distribute_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"distribute-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "distribute-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Filter updates to/from this neighbor (IP standard/extended/named access list)", "format": "string"}}}]}
    :param prefix_list_direction: {"optional": true, "enum": ["both", "receive", "send"], "type": "string", "description": "'both': both; 'receive': receive; 'send': send; ", "format": "enum"}
    :param neighbor_route_map_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"nbr-rmap-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true, "nbr-route-map": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Apply route map to neighbor (Name of route map)", "format": "string"}}}]}
    :param neighbor_filter_lists: {"minItems": 1, "items": {"type": "object"}, "uniqueItems": true, "type": "array", "array": [{"properties": {"filter-list": {"minLength": 1, "maxLength": 128, "type": "string", "description": "Establish BGP filters (AS path access-list name)", "format": "string"}, "filter-list-direction": {"enum": ["in", "out"], "type": "string", "description": "'in': in; 'out': out; ", "format": "enum"}, "optional": true}}]}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/router/bgp/{as_number}/address-family/ipv6/neighbor/ipv4-neighbor/{neighbor_ipv4}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "neighbor_ipv4"]

        self.b_key = "ipv4-neighbor"
        self.a10_url="/axapi/v3/router/bgp/{as_number}/address-family/ipv6/neighbor/ipv4-neighbor/{neighbor_ipv4}"
        self.DeviceProxy = ""
        self.maximum_prefix = ""
        self.neighbor_prefix_lists = []
        self.allowas_in_count = ""
        self.weight = ""
        self.peer_group_name = ""
        self.send_community_val = ""
        self.neighbor_ipv4 = ""
        self.inbound = ""
        self.next_hop_self = ""
        self.maximum_prefix_thres = ""
        self.route_map = ""
        self.default_originate = ""
        self.remove_private_as = ""
        self.unsuppress_map = ""
        self.allowas_in = ""
        self.activate = ""
        self.distribute_lists = []
        self.prefix_list_direction = ""
        self.neighbor_route_map_lists = []
        self.neighbor_filter_lists = []

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class BackupPeriodic(A10BaseClass):
    
    """Class Description::
    Configure backup periodically.

    Class backup-periodic supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    :param week: {"description": "Specify interval weeks", "format": "number", "optional": true, "maximum": 199, "minimum": 1, "not": "day", "type": "number"}
    :param use_mgmt_port: {"default": 0, "optional": true, "type": "number", "description": "Use management port as source port", "format": "flag"}
    :param hour: {"description": "Specify interval hours", "format": "number", "optional": true, "maximum": 65534, "minimum": 1, "not": "day", "type": "number"}
    :param system: {"default": 0, "optional": false, "type": "number", "description": "Backup system files", "format": "flag"}
    :param store_name: {"description": "profile name to store remote url", "format": "string", "minLength": 1, "optional": true, "maxLength": 31, "type": "string"}
    :param remote_file: {"optional": true, "type": "string", "description": "profile name for remote url", "format": "url"}
    :param day: {"description": "Specify interval days", "format": "number", "optional": true, "maximum": 199, "minimum": 1, "not": "hour", "type": "number"}
    :param log: {"default": 0, "optional": false, "type": "number", "description": "Backup log files", "format": "flag"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/backup-periodic/{system}+{log}`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required = [ "system","log"]

        self.b_key = "backup-periodic"
        self.a10_url="/axapi/v3/backup-periodic/{system}+{log}"
        self.DeviceProxy = ""
        self.week = ""
        self.use_mgmt_port = ""
        self.hour = ""
        self.system = ""
        self.store_name = ""
        self.remote_file = ""
        self.day = ""
        self.log = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)





from a10sdk.common.A10BaseClass import A10BaseClass


class Hd(A10BaseClass):
    
    """    :param use_mgmt_port: {"description": "Use management port as source port", "format": "flag", "default": 0, "optional": true, "not": "local", "type": "number"}
    :param image: {"optional": true, "enum": ["pri", "sec"], "type": "string", "description": "'pri': Primary image; 'sec': Secondary image; ", "format": "enum"}
    :param Device: {"optional": true, "minimum": 1, "type": "number", "maximum": 8, "format": "number"}
    :param local: {"description": "Use image from local VCS image repository (Specify an image name, format: aximage_XX_XX_XX_XX.tar.gz)", "format": "string", "minLength": 1, "not-list": ["use-mgmt-port", "file-url", "image-file"], "optional": true, "maxLength": 128, "type": "string"}
    :param staggered_upgrade_mode: {"default": 0, "optional": true, "type": "number", "description": "in staggered upgrade mode", "format": "flag"}
    :param file_url: {"not-list": ["local", "image-file"], "type": "string", "description": "File URL", "optional": true, "format": "url"}
    :param DeviceProxy: The device proxy for REST operations and session handling. Refer to `common/device_proxy.py`

Class Description::
    Hard Disk.

    Class hd supports CRUD Operations and inherits from `common/A10BaseClass`.
    This class is the `"PARENT"` class for this module.`

    

    URL for this object::
    `https://<Hostname|Ip address>//axapi/v3/upgrade/hd`.

    

    
    """
    def __init__(self, **kwargs):
        self.ERROR_MSG = ""
        self.required=[]
        self.b_key = "hd"
        self.a10_url="/axapi/v3/upgrade/hd"
        self.DeviceProxy = ""
        self.use_mgmt_port = ""
        self.image = ""
        self.Device = ""
        self.local = ""
        self.staggered_upgrade_mode = ""
        self.file_url = ""

        for keys, value in kwargs.items():
            setattr(self,keys, value)


